Se også Hund

## Dansk

Wikipedia har en artikel om:
Hund
En hund

### Etymologi

Menes at stamme fra indoeuropæisk sprog ḱʷn̥tós, fra ḱwṓ og derfra videre til germansk sprog *hundaz og fra oldnordisk hundr.

### Udtale

- IPA: (hjælp) [ˈhunˀ]. I sammensætninger startende med hunde-: IPA: (hjælp) [ˈhunə-]
- X-SAMPA: `["hun_?]`. I sammensætninger startende med hunde-: X-SAMPA: `["hun@-]`

### Substantiv

hund fælleskøn

1. (zoologi): et pattedyr af underarten Canis lupus familiaris.
     Jeg er ikke bange for hunde.
2. (slang): 100 DKK-seddel (bruges ikke i flertal)
     Vil du låne mig en hund?

#### Bøjning

Bøjning af „hund“

fælleskøn | Ental | Flertal
--- | --- | ---
ubestemt | bestemt | ubestemt | bestemt
nominativ, dativ og akkusativ | hund | hunden | hunde | hundene
genitiv | hunds | hundens | hundes | hundenes

- I sammensætninger er formen hunde- f.eks. hundehus, hundeliv.

#### Synonymer

(hunhund): en tæve (unge): en hvalp (nedsættende): en køter
|  | (slang om lille hund): en tæppetisser (babysprog): en vovse (babysprog): en vovhund

#### Afledte termer

blodhund førerhund fårehund gravhund grævlingehund hanhund hundeangst hundedage hundefoder hundefører hundegalskab hundegræs hundehoved hundehul
|  | hundehus hundehvalp hundekennel hundekiks hundekold hundekunster hundeliv hundelort hundepension hunderæd hundeslagsmål hundeslæde hundevejr hunhund
|  | hyrdehund hønsehund jagthund jordhund kamphund lænkehund muskelhund mårhund pladshund politihund præriehund puddelhund sanktbernhardshund schæferhund slædehund

#### Udtryk

- (have stor lyst til noget): At være en hund efter noget;
- (problemets egentlige årsag): Dér ligger hunden begravet;
- (at være morsom eller vittig): En vittig hund;
- (blive fattig eller alkoholiker mv.): Gå i hundene;
- (at være barsk og ufølsom): At være en hård hund;
- (skændes altid): Leve som hund og kat;
- (man gør, hvad man er vant til): Man kan ikke lære en gammel hund nye kunster;
- (man skal ikke dømme efter det ydre): Man skal ikke skue hunden på hårene;
- (hårdt liv): Det er et hundeliv;
- (meget dårligt vejr): Det er et hundevejr;
- (når man nævner at man er med i noget uden at ville virke pralende): Og mig selv, sagde hunden;
- (når man utilsigtet bringer uorden eller forstyrrelse i noget der ellers fungerer): Som en hund i et spil kegler.

#### Oversættelser

husdyr

Afrikaans: hond (af) Albansk: qen (sq) Arabisk: كلب (kalb) Baskisk: etxe-txakur (eu) Bosnisk: pas (bs) hankøn Bretonsk: ki (br) hankøn chas flertal, kiez (br) hunkøn -ed Bulgarsk: куче (bg) (kuče (bg)) Catalansk: gos (ca) hankøn, gossa (ca) hunkøn, ca (ca) hankøn Cherokee: gitli gili Chumash (Inezeño): huču Engelsk: dog (en) Esperanto: hundo (eo) Estisk: koer (et) Finsk: koira (fi) Fransk: chien (fr) hankøn Friulisk: cjan Færøsk: hundur (fo) Galicisk: can (gl) Gotisk: 𐌷𐌿𐌽𐌳𐍃 (hunds) hankøn Græsk: σκύλος (el) (skýlos) hankøn Grønlandsk: qimmeq (kl) Guarani: jagua (gn) Hawaiiansk: ʻilio Hebræisk: כלב (he) (keh-lev) Hindi: कुत्ता (hi) (kuttā) Hviderussisk: сабака (be) Indonesisk: anjing (id) Interlingua: can (ia) Interlingue: cane (ie) Inuktitut: qimmiq Irsk: madra (ga), gadhar (ga), cú (ga) Islandsk: hundur (is) Italiensk: cane (it) hankøn Japansk: 犬 (ja) (いぬ, inu) Javanesisk: asu (jv) Jiddisch: הונט (yi) (hunt) Kinesisk: 犬 (quǎn) Koreansk: 개 (ko) (gæ) Kroatisk: pas (hr) hankøn Kurdisk: se (ku) hankøn Ladinsk: cian Laotisk: ໝາ (lo) (maa) Latin: canis (la) fælleskøn Lettisk: suns (lv) Limburgsk: hóndj (li) hankøn Litauisk: šuo (lt)
|  | Lojban: gerku Makedonsk: пес (mk) (pes (mk)) Malayalam: നായ് (ml) Manchu: indahūn Maori: kurī (mi) Mongolsk: нохой (mn) (noxoy) Nederlandsk: hond (nl) hankøn Nedersorbisk: pjas Nordsamisk: beana (se) Norsk: hund, bikkje (no) Occitansk: gos (oc), can (oc) Oldgræsk: κύων (kýōn) fælleskøn Persisk: سگ (fa) (sag) Plattysk: Hund Polsk: pies (pl) hankøn Portugisisk: cão (pt) hankøn, cadela (pt) hunkøn, cachorro (pt) hankøn, cachorra (pt) hunkøn Provençalsk: can Romani ("sigøjnersk"): zhukel hankøn, zhukli hunkøn Rumænsk: câine (ro) Russisk: собака (ru) (sobaka) hunkøn, пёс (ru) (pǒs) hankøn Rætoromansk: chaun (rm) Sanskrit: s'va-na (sa) Sardinsk: cani (sc)/cane (sc), perru (sc), catteddu (sc) Serbisk: пас (sr) (pas (sr)) Skotsk gælisk: cù (gd) hankøn Slovakisk: pes (sk) hankøn, suka (sk) hunkøn Slovensk: pes (sl) hankøn Somalisk: ey (so) Spansk: perro (es) hankøn, chucho (es) hankøn Svensk: hund (sv) fælleskøn Tagalog: aso (tl) Tahitisk: ʻuri (ty) Thailandsk: หมา (th) (mǎa) Tjekkisk: pes (cs) hankøn Tok Pisin: dok Tupinambá: îagûara Tyrkisk: köpek (tr) Tysk: Hund (de) hankøn Ukrainsk: собака (uk) (sobaka), пес (uk) (pes) Ungarsk: kutya (hu) Vestfrisisk: hûn (fy) Vietnamesisk: chó (vi) (IPA: /ʧɔ́/; VIQR (vi): cho') Volapyk: dog (vo) Walisisk: ci (cy) Øvresorbisk: pos, psyk

100 DKK-seddel

Svensk: hundring (sv) fælleskøn
|  | Tysk: Hündin (de) hunkøn

## Norsk

### Etymologi

Sandsynligvis fra urgermansk *hundaz - gennem oldnordisk hundr.

### Udtale

- IPA: (hjælp) /hʉn/, X-SAMPA: `/h}n/`
- Homofoner: hun

### Substantiv

hund • hankøn Bokmål/Nynorsk • fælleskøn Riksmål

1. en hund
     Jeg har en hund.

#### Bøjning

Ental ubestemt en hund
|  | Ental bestemt hunden
|  | Flertal ubestemt hunder
|  | Flertal bestemt hundene

#### Udtryk

Udtryk

- det er der hunden ligger begravet
- en skal ikke skue hunden på hårene
- fryse som en hund
- gale hunder får revet skinn
- gå i hundene
- jage en vekk som en hund
- leve som hund og katt
- skamme seg som en hund
- være en hund etter noe
- være lydig som en hund

#### Synonymer

bikkje, kjøter, vovvov, bisk, rakke

#### Beslægtede ord og fraser

buhund, elghund, fuglehund, harehund, trekkhund

### Kilder

- Niels Åge Nielsen: Ordenes Historie ISBN 87-7789-000-0

## Svensk

### Etymologi

Sandsynligvis fra urgermansk *hundaz - gennem oldnordisk hundr.

### Udtale

- audio |
  (fil)

- IPA: (hjælp) /hɵnd/, X-SAMPA: `/h8nd/`

### Substantiv

hund fælleskøn

1. en hund
     Här ligger en hund begraven.
       Her ligger hunden begravet.

#### Bøjning

Bøjning af hund | Ental | Flertal
--- | --- | ---
fælleskøn | Ubestemt | Bestemt | Ubestemt | Bestemt
Nominativ | hund | hunden | hundar | hundarna
Genitiv | hunds | hundens | hundars | hundarnas

#### Beslægtede ord og fraser

Relaterede opslag

fårhund fähund hundaktig hundan hundbajs hundben hundbett hundbiten hundblick hundbuss | hunddagis hunddjur hunddressyr hundfoder hundförare hundgalenskap hundgård hundgöra hundhuvud hundhår | hundjobb hundkapplöpning hundkex hundkoja hundkoppel hundkräk hundkyrkogård hundkäx hundlik hundliv | hundloka hundlort hundmat hundnos hundpatrull hundpsykolog hundsfottera hundsim hundskall hundskatt | hundskinn hundskit hundskola hundslagsmål hundsläde hundspann Hundstjärnan hundtoalett hundtunga hundutställning | hundvakt hundvalp hundviol hundväder hundår hundägare hundäxing hundöga hundöra hynda | knähund vakthund

#### Synonymer

- vofsing
- vovve

### Kilder

- hund i Svenska Akademiens ordbok